@@ -3,8 +3,12 @@ import os
 import re
 import time
 import pathlib
-from commontest import rdiff_backup, Myrm, compare_recursive, \
+from commontest import (
+    rdiff_backup, Myrm, compare_recursive,
     old_test_dir, abs_test_dir, get_increment_rp, xcopytree
+)
+import commontest as comtst
+import fileset
 from rdiff_backup import Globals, log, rpath, robust, FilenameMapping, Time, selection
 """Regression tests"""
 
@@ -805,13 +809,31 @@ class FinalBugs(PathSetter):
 
         """
         self.delete_tmpdirs()
-        bigrp = Local.get_src_local_rp('bigdir')
+
+        # create the bigdir on the fly
+        bigdir_path = os.path.join(comtst.abs_test_dir, b"cmd_bigdir")
+        bigrp = rpath.RPath(Globals.local_connection, bigdir_path)
+        bigdir_struct = {
+            "subdir{}": {
+                "range": 4, "contents": {
+                    "subdir{}": {
+                        "range": 50, "contents": {
+                            "file{}": {"range": 50, "size": 1024}
+                        }
+                    }
+                }
+            }
+        }
+        fileset.create_fileset(bigdir_path, bigdir_struct)
+
         rdiff_backup(True, True, bigrp.path, Local.rpout.path)
         rp = bigrp.append('subdir3', 'subdir49', 'file49')
         self.assertTrue(rp.isreg())
         rp.touch()
         rdiff_backup(True, True, bigrp.path, Local.rpout.path)
 
+        fileset.remove_fileset(bigdir_path, bigdir_struct)
+
 
 if __name__ == "__main__":
     unittest.main()
